@@ -9,7 +9,7 @@ import datetime
 
 class DBAPI20Test(unittest.TestCase):
     driver = CUBRIDdb
-    connect_args = ('CUBRID:localhost:33000:demodb:::', 'public', '')
+    connect_args = ('CUBRID:test-db-server:33000:demodb:::', 'public', '')
     connect_kw_args = {}
     connect_kw_args2 = {'charset': 'utf8'}
 
